spoon.transports.transports

Package spoon :: Package transports :: Module transports |
[show private | hide private]
[frames | no frames]

## Module spoon.transports.transports

Classes
`LinkMessage` | Link message is the wrapper which will contain messages sent between two directly connected nodes.
`SpoonRPCHello` | This object is sent as a very simple form of initial negotiation.

Exceptions
`TransportException` |

Function Summary
| `decode_linkmessage(fd, tag)`
| `encode_linkmessage(fd, obj)`

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net